# synthetic
Synthetic Cognitions framework for developing language model agents.

# Mission
In Synthetic Cognition we are commited to provide developers the latest advancements in language model agents. This way we make adoption and innovation easyer for everyone.

# Values
- Open Knowledge: All the research and products will be fully open source so everyone has access to them and the posibility to iterate on top of them.

- Innovation: We do not only make an easy way to apply current advancements, we are constantly pursuing new innovations on our field.

# Vission
We want to be the Verecel of Language Model Agents.

# Problem
- Current frameworks are based on the ReAct architecture and have no or very limited support for new advancements.
- Cloud services targeting generative AI focus on deployment of models but in the case of agents you have to manage it yourself.

# Solution
The solution is to create a new framework built from the ground up to support integral changes to the agent architecture to ease the development of new architectures and offer agent hosting services to keep developers in what they are good at, AI.

# Product
We are developping the **synthetic** library with an easy to use API but with the adaptability to suport changes in the base architecture. We are also introducing new features to agents that allow to solve fundamental problems of the current architectures.
All of the library will be designed to make deployment on the **Synthetic Cloud** fast and continuous.

# Market Oportunity
More than 400 public repositories (>100 stars) are currently dependent on langchain, including some of the leading AGI and language model agent projects.

OpenAI generated 1B since launched ChatGPT, and almost all the revenue comes from the API. All this are busineses spending in models, but they need to build further infrastructure to make those models useful, there is where we come in. 

//TODO: continue

# Customer
We are targeting language model agent developers, from the newly initiated ones to experts.
- New developers: (more and more thanks to the generative AI boom) want an easy to use API, but will follow what expert developers use.
- Expert developers: want a verstile framework they can use to implement their new developments easily. Spend money on AWS/Azure/Google Cloud deployment for their agents and in the OpenAI/HuggingFace APIs to get access to powerful models.

# Competition
- langchain: it is the current leading framework for language model agents.
	* PROS: easy to use api, broad adoption and good ReAct implementation.
	* CONS: not good suport for different architectures and complex deployment.
- Cloud providers: Majority of agents are now running on servers hosted by AWS and other cloud providers, but the deployment is complicated to unexperienced cloud developers (AI developers)

# Business Model
- free prototyping: we will offer free hosting for prototypes
- paid api: when deploying your agent you will pay for API usage
- model hosting: If want to use your own model or an open source model we can host it for you

# Partners
**Model providers**: we can partner with them to archive lower inference times for our hosted agents. (OpenAI, HuggingFace, Anthropic, ...)

# Go-to-market
- Offer a alpha-framework that allows developers to use new concepts + paper explainig them -> atract experienced developers and posible colaborators
- Make our framework stand-alone (no dependent on langchain) and with a cli that generates a functional API for prototyping.
- Offer a Synthetic Cloud for deploying agent into production enviroments

# Road Map
- Versitile function calling available (0.1.0) [2 weeks]
- Add suport for tags (0.2.0) [December]
- Add suport for widgets (0.3.0) [January - February]
- Publish reaserch paper explaining above
- Make synthetic stand-alone (1.0.0) [May-June]
- Make synthetic cli [July]

# KPIs
- Public repos using **synthetic**
- **synthetic** downloads
- Github stars + contributions to the repo
- Paper citation and views

# Web - Social Networks
- Synthetic Cognition official [web](https://carlosferlo.quarto.pub/synthetic-cognition/)

# Team
- Carlos Fernández Lorán ounder]
	* Second year mathematics student
	* Self-tought AI reasercher with experience building language model agent architectures
